| Title: | R package for mapping Scotland health data for a Health Index |
|---|---|
| Description: | A package to distribute and summarise on Scottish health data. |
| Authors: | First Last [aut, cre] (ORCID: YOUR-ORCID-ID) |
| Maintainer: | First Last <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-01 10:27:56 UTC |
| Source: | https://github.com/humaniverse/healthindexscotland |
A dataset containing statistics on the rate of patient admissions for all alcohol related admissions in each Council, 2021/22.
lives_alcohol_misuselives_alcohol_misuse
A data frame with 32 rows and 3 variables:
Local Authority Code
Rate of patient admissions per 100k population, based on number of patient admissions and using European Age-sex Standardised Rates. The number of patients is defined as the number of unique individuals treated within the financial year. Patients are counted only once in the financial year in which they have an alcohol-related stay, even though the same patient may be admitted to hospital several times in a year. Mid 2022 population estimates are used.
Financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of cancer screening uptake in each Council, 2020-2022/
lives_cancer_screeninglives_cancer_screening
A data frame with 32 row and 3 variables:
Local Authority Code
Percentage of cancer screening uptake. Only bowel cancer screening uptake is included here.
Time period - three year aggregates
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics on childhood vaccine coverage in each Council, 2022/23.
lives_child_vaccine_coveragelives_child_vaccine_coverage
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of vaccine coverage. Includes childhood immunisation statistics (6in1, PCV, rotavirus, MenB, (12 months); 6in1, MMR1, Hib/MenC, PCVb, MenB Booster (24 months); 6in1, MMR1, Hib/MenC, 4in1, MMR2 (3-5 years); MMR1, 4in1, MMR2 (4-6 years))
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the rate of drug related hospital stays in each Council, 2021/22.
lives_drug_misuselives_drug_misuse
A data frame with 32 rows and 3 variables:
Local Authority Code
Rate of hospital stays per 100k population, using European Age-sex Standardised Rates.A hospital stay, also described as a continuous inpatient stay or CIS, is defined as an unbroken period of time that a patient spends as an inpatient or day-case. During a stay a patient may have numerous episodes as they change consultant, significant facility, speciality and/or hospital. Stays are counted at the point of discharge, when all diagnostic information regarding the full stay is available. Mid 2022 population estimates are used.
Financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on early childhood developmental concerns in each Council, 2022-23.
lives_early_years_developmentlives_early_years_development
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of developmental reviews with a concern in one or more domains, out of total number of recorded reviews while child is 2 and in the cohort.
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on fruit and vegetable consumption in each Council, 2016-19.
lives_healthy_eatinglives_healthy_eating
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of people that consume 5 portions or more of fruit and vegetable per day
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on percentage of adults (excluding pregnant women) diagnosed with high blood pressure, by Council (2018-2022).
lives_high_blood_pressurelives_high_blood_pressure
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of adults (excluding pregnant women) diagnosed with high blood pressure
Time period - four year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/sg-scottish-health-survey/
A dataset containing percentage babies born not at a healthy birth weight.
lives_low_birth_weightlives_low_birth_weight
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of babies born not at a healthy birth weight
Time period - three year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics on Provisional National 5 Attainments in Maths and English, on results day, in each Council, August 2024
lives_national_five_attainmentlives_national_five_attainment
A data frame with 32 rows and 3 variables:
Local Authority Code
Grade A-C percentage in Maths and English (average of the two subjects taken)
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.sqa.org.uk/sqa/105123.html
A dataset containing statistics on percentage of adults clinically classed as overweight and obese in each Council, 2016-19.
lives_overweight_obesity_adultslives_overweight_obesity_adults
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of adults clinically classed as overweight and obese.
Time frame
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on percentage of children clinically classed as overweight, obese, and severely obese in each Council, 2022/23.
lives_overweight_obesity_childrenlives_overweight_obesity_children
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of children clinically classed as overweight, obese, and severely obese. BMI is used as the unit of measurement. Based on children in Primary 1 (aged 4-5).
School Year period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on activity levels in each Council, 2018-22.
lives_physical_activitylives_physical_activity
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of people that meet the recommended activity levels
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing crude rate of school exclusion rate 1,000 aged 15-19 in each Council, 2019-2021.
lives_pupil_absencelives_pupil_absence
A data frame with 32 rows and 3 variables:
Local Authority Code
Crude exclusion rate of pupil absence per 1,000 students
School year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics on very low activity levels in each Council, 2018-22.
lives_sedentary_behaviourlives_sedentary_behaviour
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of people with very low activity levels, defined as less than 30 minutes activity a week
Time period - four year period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/sg-scottish-health-survey/
A dataset containing statistics on rates of chlamydia per 100k in each council, 2019. To note: only chlamydia has been included here as data is missing for gonorrhoea. England's Health Index examines total number of people tested for one or more sexually transmitted infections.
lives_sexual_healthlives_sexual_health
A data frame with 32 rows and 3 variables:
Local Authority Code
Rate of chlamydia per 100,000
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on smoking status in each Council, 2018-22.
lives_smokinglives_smoking
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of people that are current smokers
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing crude rate of teenage pregnancies per 1,000 aged 15-19 in each Council, 2019-2021.
lives_teenage_pregnancylives_teenage_pregnancy
A data frame with 32 rows and 3 variables:
Local Authority Code
Crude rate of teenage pregnancies per 1,000 females aged 15-19
Time period - three year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing data on participation of young people in education, training or employment, by Council (2023).
lives_young_people_traininglives_young_people_training
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of 16-19 year olds in education, training or employment
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics from an age-sex standardised rate for all causes of mortality per 100k, by Council (2023).
people_all_mortalitypeople_all_mortality
A data frame with 32 rows and 3 variables:
Local Authority Code
age-sex standardised rate for all causes of mortality per 100k
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of anxiety out of 10, by Council (2022-23) except Orkney Islands (2020-21).
people_anxietypeople_anxiety
A data frame with 32 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of anxiety out of 10 - 10 is most anxious, 1 is least anxious
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on age-standardised death rates per 100k, by Council (2019-2021).
people_avoidable_deathspeople_avoidable_deaths
A data frame with 32 rows and 3 variables:
Local Authority Code
Age-standardised avoidable mortality rates per 100k
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on cancer registration per 100k, standardised by age-sex (2019-2021).
people_cancerpeople_cancer
A data frame with 32 rows and 3 variables:
Local Authority Code
Cancer registrations per 100k, standardised by age-sex
Time period - three year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics on the percentage of discharges per 1,000 for cardiovascular conditions in each Council, 2022/23.
people_cardiovascular_conditionspeople_cardiovascular_conditions
A data frame with 32 variables and 3 variables:
Local Authority Code
Percentage of total cardiovascular discharges per 1k population. Cardiovascular conditions includes angina, coronary heart disease, heart attack, and heart failure. Scottish 2022 mid year population estimates were used
Financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of long-stay nursing care residents medically diagnosed with dementia, by Council (2023-24).
people_dementiapeople_dementia
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of long-stay nursing care residents medically diagnosed with dementia, by Council. England's Health Index dementia indicator collects data on the weighted number of people answering yes to Alzheimer's disease or other cause of dementia in the national GP Patient Survey. The only available dementia data at Local Authority level in Scotland focuses on nursing care residents across all sectors.
Time period - census data in the year up to 31/03/2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.opendata.nhs.scot/dataset/care-home-census/resource/9bf418aa-c54d-45d3-8306-023e81f49f60
Crude prevalence of diabetes
people_diabetespeople_diabetes
A data frame with 32 rows and 3 variables:
Local Authority Code
Crude prevalence of diabetes (all types)
...
https://www.diabetesinscotland.org.uk/wp-content/uploads/2023/10/Scottish-Diabetes-Survey-2022.pdf
A dataset containing statistics on the percentage of people aged 16-64 with long-term health problem/disability that limits daily activities, by Council (2022).
people_disabilitypeople_disability
A data frame with 32 rows and 3 variables:
Local Authority Code
percentage of people aged 16-64 with long-term health problem/disability that limits daily activities by a lot or by a little.
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of happiness out of 10, by Council (2022-23) except Orkney Islands (2020-21).
people_happinesspeople_happiness
A data frame with 32 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of happiness out of 10; 10 - most happy, 1 - least happy
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on average healthy life expectancy for men and women, by Council (2019-2021).
people_healthy_life_expectancypeople_healthy_life_expectancy
A data frame with 32 rows and 3 variables:
Local Authority Code
Weighted population average healthy life expectancy for men and women
Time period - three year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics on the rate of infant mortality in each Council, 2017-2021.
people_infant_mortalitypeople_infant_mortality
A data frame with 32 rows and 3 variables:
Local Authority Code
Rate of infants per 1k that have died under the age of 1
Time period - five year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics of personal ratings on feelings of life satisfaction out of 10, by Council (2022-23) except Orkney Islands (2020-21).
people_life_satisfactionpeople_life_satisfaction
A data frame with 32 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of life satisfaction out of 10, 10 - most satisfied, 1 - least satisfied
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics of personal ratings on feelings of life worthwhileness out of 10, by Council (2022-23) except Orkney Islands (2020-21).
people_life_worthwhilenesspeople_life_worthwhileness
A data frame with 32 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of life worthwhileness out of 10, 10 - most worthwhile, 1 - least worthwhile
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics of population prescribed drugs for mental health conditions, by Council (2020-21).
people_mental_health_conditionspeople_mental_health_conditions
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of population prescribed drugs for anxiety, depression or psychosis
Time period - financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing statistics on percentage of adults aged 18+ with Rheumatoid Arthritis, by Council (2016).
people_musculoskeletal_conditionspeople_musculoskeletal_conditions
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of adults aged 18+ with Rheumatoid Arthritis. England's Health Index musculoskeletal conditions gathers data on Weighted number of people answering yes to 'Arthritis or ongoing problem with back or joints'.
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics from deaths by suicide, by Council.
people_suicidespeople_suicides
A data frame with 32 rows and 3 variables:
Local Authority Code
Deaths from suicide (16+). Age standardised rate per 100,000.
Time period - 5 year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://scotland.shinyapps.io/ScotPHO_profiles_tool/
A dataset containing population-weighted annual mean PM2.5 data for 2023, by Scottish Council Area. Uses the anthropogenic component.
places_air_pollutionplaces_air_pollution
A data frame with 32 rows and 3 variables:
Local Authority Code
Population-weighted annual mean PM2.5
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://uk-air.defra.gov.uk/data/pcm-data
A dataset containing statistics on the percentage of children (aged under 16) living in absolute low income families in each Council, 2022-23.
places_child_povertyplaces_child_poverty
A data drame with 32 rows and 3 variables:
Local Authority Code
Percentage of children under 16 living in absolute low incomes families (where a household's income is below 60% of the median income in 2010/11, adjusted for inflation).
Financial Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing the percentage of people who rated their GP practice as positive for the care provided, by Council (2023/24)
places_gp_appointmentsplaces_gp_appointments
A data frame with 32 rows and 3 variables:
Local Authority Code
The percentage of people who rated their GP practice as positive for the care provided
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.gov.scot/publications/health-and-care-experience-survey-results-by-geography/
A dataset containing the average (median) travel time (in minutes) to the nearest GP in each Council Area. This is based on the travel time to the nearest GP in each Intermediate Zone within a Council Area. This may include GPs located in England.
places_gp_travel_timeplaces_gp_travel_time
A data frame with 32 rows and 3 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest GP among all the Intermediate Zones within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing statistics on the percentage of households experiencing household overcrowding, per Council (2022). Household overcrowding is defined as households with an occupancy rating of -1 or lower.
places_household_overcrowdingplaces_household_overcrowding
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of households experiencing household overcrowding
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.scotlandscensus.gov.uk/documents/scotland-s-census-2022-housing-chart-data/
A dataset containing statistics on percentage of households with home internet access, by Council (2022). To Note: Data for Moray and South Ayrshire is missing.
places_internet_accessplaces_internet_access
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of households with home internet access. Data is missing for Moray and South Ayrshire
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.gov.scot/publications/scottish-household-survey-2022-key-findings/documents/
A dataset containing job related training in Scottish councils.
places_job_trainingplaces_job_training
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of all who received job related training in last 4 wks - aged 16-64
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.nomisweb.co.uk/datasets/apsnew
A dataset containing statistics on 'low-level crime' per 10,000 people in Scottish Council Areas. England's Health Index defines 'low-level crimes' as bicycle theft and shoplifting. Of the two, Scotland only publishes shoplifting data. There are other crimes listed that could potentially count as 'low-level crimes' but we will avoid making a potentially arbitrary judgement here.
places_low_level_crimeplaces_low_level_crime
A data frame with 32 rows and 3 variables:
Local Authority Code
Number of low-level crimes per 10,000 people
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.gov.scot/publications/recorded-crime-scotland-2023-24/
A dataset containing statistics on 'personal crime' per 10,000 people in Scottish Council Areas. 'Personal crime' is defined as
Non-sexual crimes of violence (includes robbery)
Sexual crimes
Damage and reckless behaviour
places_personal_crimeplaces_personal_crime
A data frame with 32 rows and 3 variables:
Local Authority Code
Number of personal crimes per 10,000 people
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.gov.scot/publications/recorded-crime-scotland-2023-24/
A dataset containing the average (median) travel time (in minutes) to the nearest pharmacy in each Council Area. This is based on the travel time to the nearest pharmacy in each Intermediate Zone within a Council Area. This may include pharmacies located in England.
places_pharmacy_travel_timeplaces_pharmacy_travel_time
A data frame with 32 rows and 3 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest pharmacy among all the Intermediate Zones within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing statistics on the percentage of addresses with access to private outdoor space, by Council (2020).
places_private_outdoor_spaceplaces_private_outdoor_space
A data frame with 32 rows and 3 variables:
Local Authority Code
Percentage of addresses with access to private outdoor space
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing number of people killed or seriously injured in each Scottish Council Area in 2022 (latest available data), normalised by the area in each Council Area (in square km).
places_road_safetyplaces_road_safety
A data frame with 32 rows and 3 variables:
Local Authority Code
Number of people killed or seriously injured, normalised by land area (km^2)
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://statistics.gov.scot/data/road-safety
A dataset containing statistics on number of homelessness applications where at least one member of the household was sleeping rough within the previous three months, normalised per 100,000 residents.
places_rough_sleepingplaces_rough_sleeping
A data frame with 32 rows and 3 variables:
Local Authority Code
number of homelessness applications where at least one member of the household was sleeping rough within the previous three months, normalised per 100,000 residents.
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.gov.scot/publications/homelessness-in-scotland-2023-24/
A dataset containing the average (median) travel time (in minutes) to the nearest sports centre in each Council Area. This is based on the travel time to the nearest sports centre in each Intermediate Zone within a Council Area. This may include sports centres located in England.
places_sports_centre_travel_timeplaces_sports_centre_travel_time
A data frame with 32 rows and 3 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest sports centre among all the Intermediate Zones within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing volume of road traffic (millions of vehicle miles per square kilometre) in Scottish Local Authorities.
places_traffic_volumeplaces_traffic_volume
A data frame with 32 rows and 3 variables:
Local Authority Code
The raw local authority traffic figures give the total volume (vehicle miles) of traffic across each local authority for the whole year.
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://roadtraffic.dft.gov.uk/
A dataset containing statistics on estimated unemployment rates in each Council, 2021-22. Estimates based on a model which utilises the Annual Population Survey estimates of unemployment along with the Claimant Count averaged over 12 months.
places_unemploymentplaces_unemployment
A data frame with 32 rows and 3 variables:
Local Authority Code
Estimated percentage of people that are unemployed. Unemployment is defined as someone aged 16+ without a job who were available to start work in the two weeks following their interview and who had either looked for work in the four weeks prior to interview or were waiting to start a job they had already obtained
Financial Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the rate of non-fatal workplace injuries per 100,000 in each Council, 2022-23.
places_workplace_safetyplaces_workplace_safety
A data frame with 32 rows and 3 variables:
Local Authority Code
Rate of non-fatal employee injuries per 100k population
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.hse.gov.uk/statistics/tables/index.htm#riddor